==> libgii-0.1.tar.gz: libgii-0.1/gg/plat.h <==
/* $Id: plat.h,v 1.6 1998/12/13 22:05:05 marcus Exp $
******************************************************************************

   LibGG internal definitions

   Copyright (C) 1998	Marcus Sundberg		[marcus@ggi-project.org]
  
   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#ifndef _GG_INTERNAL_PLAT_H
#define _GG_INTERNAL_PLAT_H

#include "config.h"

#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

/* Mutex for protecting LibGG global data */
extern void	*_gg_global_mutex;

#if defined(__GNUC__) && !defined(inline)
#define inline __inline__
#endif

#if  defined(__CYGWIN32__) \
  || defined(__MINGW32__)
#ifndef __WIN32__
#define __WIN32__
#endif
#endif

#ifdef __WIN32__
#define CHAR_DIRDELIM '\\'
#define STRING_DIRDELIM "\\"
#else
#define CHAR_DIRDELIM '/'
#define STRING_DIRDELIM "/"
#endif

#ifdef _WIN32
#include <windows.h> 
#define GGOPENLIB(filename)	LoadLibrary((filename))
#define GGOPENLIBGLOBAL(filename) GGOPENLIB(filename)
#define GGGETSYM(handle,sym)	GetProcAddress((handle),(sym))
#define GGCLOSELIB(handle)	FreeLibrary((handle))
#else /* _WIN32 */
#include <dlfcn.h>
#ifdef RTLD_LAZY
#define GGOPENLIB(filename)		dlopen((filename), RTLD_LAZY)
#ifdef RTLD_GLOBAL
#define GGOPENLIBGLOBAL(filename)	dlopen((filename), RTLD_LAZY | RTLD_GLOBAL)
#else
#define GGOPENLIBGLOBAL(filename)	dlopen((filename), RTLD_LAZY)
#endif /* RTLD_GLOBAL */
#elif defined(DL_LAZY)
#define GGOPENLIB(filename)		dlopen((filename), DL_LAZY)
#define GGOPENLIBGLOBAL(filename)	dlopen((filename), DL_LAZY)
#else
#error This system has an unknown dlopen() call !!!
#endif /* RTLD_LAZY */
#define GGGETSYM(handle,sym)	dlsym((handle),(sym))
#define GGCLOSELIB(handle)	dlclose((handle))
#endif /* _WIN32 */

#if defined(__OpenBSD__) || defined(__DJGPP__) /* a.out or non-Win32 COFF systems */
#define GG_SYMPREFIX		"_"
#endif

#endif /* _GGI_INTERNAL_PLAT_H */

==> libgii_0.6.orig.tar.gz: libgii-0.6/gg/plat.h <==
/* $Id: plat.h,v 1.9 1999/03/02 02:29:43 marcus Exp $
******************************************************************************

   LibGG internal definitions

   Copyright (C) 1998	Marcus Sundberg		[marcus@ggi-project.org]
  
   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#ifndef _GG_INTERNAL_PLAT_H
#define _GG_INTERNAL_PLAT_H

#include "config.h"

#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

/* Mutex for protecting LibGG global data */
extern void	*_gg_global_mutex;

#if defined(__GNUC__) && !defined(inline)
#define inline __inline__
#endif

#if  defined(__CYGWIN32__) \
  || defined(__MINGW32__)
#ifndef __WIN32__
#define __WIN32__
#endif
#endif

#ifdef __WIN32__
#define CHAR_DIRDELIM '\\'
#define STRING_DIRDELIM "\\"
#else
#define CHAR_DIRDELIM '/'
#define STRING_DIRDELIM "/"
#endif

#ifdef _WIN32
#include <windows.h> 
#define GGOPENLIB(filename)	LoadLibrary((filename))
#define GGOPENLIBGLOBAL(filename) GGOPENLIB(filename)
#define GGGETSYM(handle,sym)	GetProcAddress((handle),(sym))
#define GGCLOSELIB(handle)	FreeLibrary((handle))
#define GGDLERROR()		NULL
#else /* _WIN32 */
#include <dlfcn.h>
#ifdef RTLD_LAZY
#define GGOPENLIB(filename)		dlopen((filename), RTLD_LAZY)
#ifdef RTLD_GLOBAL
#define GGOPENLIBGLOBAL(filename)	dlopen((filename), RTLD_LAZY | RTLD_GLOBAL)
#else
#define GGOPENLIBGLOBAL(filename)	dlopen((filename), RTLD_LAZY)
#endif /* RTLD_GLOBAL */
#elif defined(DL_LAZY)
#define GGOPENLIB(filename)		dlopen((filename), DL_LAZY)
#define GGOPENLIBGLOBAL(filename)	dlopen((filename), DL_LAZY)
#else
#error This system has an unknown dlopen() call !!!
#endif /* RTLD_LAZY */
#define GGGETSYM(handle,sym)	dlsym((handle),(sym))
#define GGCLOSELIB(handle)	dlclose((handle))
#define GGDLERROR()		dlerror()
#endif /* _WIN32 */

#if defined(SYMBOL_UNDERSCORE) || defined(__OpenBSD__)
#define GG_SYMPREFIX		"_"
#endif

#endif /* _GGI_INTERNAL_PLAT_H */
